#!/bin/bash
# Active Monitor Script for UPS
#
# Author: Joshua Uziel
# Sun Microsystems, Inc. 2001.  All rights reserved.
# $Id: am_ups.sh,v 1.14.2.1 2002/02/16 05:11:06 uzi Exp $

# Get the current configuration info and the statecodes
. /etc/sysconfig/ups
. /usr/sausalito/swatch/statecodes

UPSC="/usr/bin/upsc"

# Set defaults
if [ -z $batt_yellow ]; then
	batt_yellow="80"
fi
if [ -z $batt_red ]; then
	batt_red="50"
fi
FINAL_RET=$AM_STATE_GREEN

# First we get the battery percentage line.
BATTLINE=`$UPSC $HOST | grep BATTPCT`
if [ "$?" != "0" ]; then
	# Attempt to restart ups stuff if we can't connect.
	/etc/rc.d/init.d/ups restart > /dev/null 2>&1

	# If it fails again, die.
	BATTLINE=`$UPSC $HOST | grep BATTPCT`
	if [ "$?" != "0" ]; then
		echo -ne "[[base-ups.amCantConnect]]"
		exit $AM_STATE_RED
	fi
fi

# Report status based on the battery percentage left.
BATTPCT=`echo $BATTLINE | sed -e 's/.*: //' -e 's/\..*//' -e 's/^0*//'`
if [ "$BATTPCT" -lt $batt_yellow ]; then
	msg="[[base-ups.amBatteryLow,level=\"$batt_yellow\"]]  "
	FINAL_RET=$AM_STATE_YELLOW
fi
if [ "$BATTPCT" -lt $batt_red ]; then
	msg="[[base-ups.amBatteryLow,level=\"$batt_red\"]]  "
	FINAL_RET=$AM_STATE_RED
fi
if [ "$BATTPCT" = "" ]; then		# No battery level read
	msg="[[base-ups.amCantConnect]]  "
	FINAL_RET=$AM_STATE_RED
fi

# Get the status of the UPS... if OB (On Battery), then red alert.
STATUS=`$UPSC $HOST | grep STATUS | sed 's/.*: //'`
if [ "$STATUS" = "OB" ]; then
	echo -ne "[[base-ups.amOnBattery]]  "
	FINAL_RET=$AM_STATE_RED
fi


if [ $FINAL_RET -eq $AM_STATE_GREEN ]; then
	msg="[[base-ups.amAllOK]]  "
fi

echo -ne $msg
exit $FINAL_RET
